diff --git a/flake.nix b/flake.nix
index 0a92e23d..b093ded5 100644
--- a/flake.nix
+++ b/flake.nix
@@ -72,7 +72,6 @@
             ++ (lib.optional stdenv.isLinux lldb)
             ++ (lib.optional stdenv.isDarwin darwin.apple_sdk.frameworks.CoreFoundation);
           shellHook = ''
-            export HELIX_RUNTIME="$PWD/runtime"
             export RUST_BACKTRACE="1"
             export RUSTFLAGS="''${RUSTFLAGS:-""} ${rustFlagsEnv}"
           '';
diff --git a/default.nix b/default.nix
index 2f8ea435..d94e707d 100644
--- a/default.nix
+++ b/default.nix
@@ -16,6 +16,7 @@
     ./screenshot.png
     ./book
     ./docs
+    ./runtime
     ./flake.lock
     (fs.fileFilter (file: lib.strings.hasInfix ".git" file.name) ./.)
     (fs.fileFilter (file: file.hasExt "svg") ./.)
@@ -66,7 +67,7 @@ in
     doCheck = false;
     strictDeps = true;
 
     # Sets the Helix runtimedir to the grammars
     env.HELIX_DEFAULT_RUNTIME = "${runtimeDir}";
 
     # Get all the application stuff in the output directory.
@@ -66,7 +67,7 @@ in
     strictDeps = true;
 
-    # Sets the Helix runtimedir to the grammars
+    # Sets the Helix runtime dir to the grammars
     env.HELIX_DEFAULT_RUNTIME = "${runtimeDir}";
 